<p align="center"><img src="https://raw.githubusercontent.com/Badgie/spotirec/master/img/header/header-600x200.png" alt="spotek"/></p>


<p align="center">
  <img alt="GitHub release" src="https://img.shields.io/github/release/badgie/spotirec.svg">
  <img alt="GitHub" src="https://img.shields.io/github/license/badgie/spotirec.svg">
  <img alt="AUR votes" src="https://img.shields.io/aur/votes/spotirec-git.svg?label=AUR%20votes">
  <img alt="GitHub last commit (master)" src="https://img.shields.io/github/last-commit/badgie/spotirec/master.svg?label=last%20update">
</p>

# Spotirec
A tool that can create a playlist of recommendations based on the user's top artists or tracks, or genres extracted from top artists with various parameters - a sort of Discover Weekly on demand. Also includes functionality for various other Spotify-related actions, such as saving the currently playing track.


#### [Installation](https://github.com/Badgie/spotirec/wiki/Installation)

#### [Usage](https://github.com/Badgie/spotirec/wiki/Usage)

#### [Troubleshooting](https://github.com/Badgie/spotirec/wiki/Troubleshooting)

#### [Development](https://github.com/Badgie/spotirec/wiki/Development)

#### [Wiki](https://github.com/Badgie/spotirec/wiki)